cynthia_websites_mini_client/pottery/molds/cindy_simple

Cindy Simple Layout module

Default OOTB layout for Cynthia Mini. Focused on simplicity while offering a clean, modern experience.

Values

pub fn menu_1(
  from model: model_type.Model,
) -> List(@internal Element(messages.Msg))

Cindy Simple only has one menu, shown on the top of the page. But we still count it as menu 1.

pub fn page_layout(
  from content: @internal Element(messages.Msg),
  with variables: dict.Dict(String, dynamic.Dynamic),
  store model: model_type.Model,
) -> @internal Element(messages.Msg)

cindy layout for pages.

Dict keys:

  • content
pub fn post_layout(
  from content: @internal Element(messages.Msg),
  with variables: dict.Dict(String, dynamic.Dynamic),
  store model: model_type.Model,
) -> @internal Element(messages.Msg)
Search Document