cynthia_websites_mini_client/pottery/molds/ownit

Ownit layout

Custom layout for Cynthia Mini. Allows to create own templates in Handlebars.

Ownit is a unique layout in the sense that, it does not contain a layout, it’s merely a wrap around Handlebars to allow own templates to be used in Cynthia Mini.

Writing templates for ownit

Writing templates for ownit can be done in the Handlebars language. Your template should be stored under [variables] -> ownit_template as a "string" or as a { path = "filename.hbs" } or { url = "some-site.com/name.hbs" } url.

Available context variables:

Values

pub fn main(
  from content: @internal Element(messages.Msg),
  with variables: dict.Dict(String, dynamic.Dynamic),
  store model: model_type.Model,
  is_post is_post: Bool,
) -> @internal Element(messages.Msg)
Search Document