cynthia_websites_mini_client/pottery/molds/minimalist

Minimalist Layout Module

A clean, distraction-free layout focused on content.

Values

pub fn menu_1(
  from model: model_type.Model,
) -> List(@internal Element(messages.Msg))

Generate primary menu items

pub fn page_layout(
  from content: @internal Element(messages.Msg),
  with variables: dict.Dict(String, dynamic.Dynamic),
  store model: model_type.Model,
) -> @internal Element(messages.Msg)

Minimalist page layout

Creates a clean, focused layout for regular pages with emphasis on readability and minimal distractions.

pub fn post_layout(
  from content: @internal Element(messages.Msg),
  with variables: dict.Dict(String, dynamic.Dynamic),
  store model: model_type.Model,
) -> @internal Element(messages.Msg)

Minimalist post layout

Creates a clean layout for blog posts with minimal distractions and subtle metadata display.

Search Document